VectorFunction

Enum VectorFunction 

pub enum VectorFunction {
    TwoD(_VectorFunction2D),
    ThreeD(_VectorFunction3D),
}
Vector functions for 2D and 3D spaces

Vector Function

Vector functions are functions of two or three variables that return two or three-dimensional Vectors.
You can create one using the [vector_function!] macro.
Vector functions evaluate just like Functions and rust functions, and you can even evaluate them on Vectors.
You can take its partial derivatives with the [claire_dxv!], [claire_dyv!] and [claire_dzv!] macros, adding the ‘v’ at the end to signal that it is the partial of a vector function, and that it returns a Vector as such.
Furthermore, you can use the [curl!] and [div!] macro to evaluate its rotational and divergence at a point. \

Examples

use claire_vector::*; let v:VectorFunction = vector_function!(x, y, -y, x); assert_eq!(v(0., 1.), vector!(-1, 0)); // v(0, 1) = (-1, 0)

Variants



TwoD(_VectorFunction2D)



ThreeD(_VectorFunction3D)