Enum VectorFunction Copy item path Source pub enum VectorFunction {
TwoD(_VectorFunction2D),
ThreeD(_VectorFunction3D),
}Expand description Vector functions for 2D and 3D spaces
 Vector Function
Vector functions are functions of two or three variables that return two or three-dimensional Vector s.
You can create one using the [vector_function!] macro.
Vector functions evaluate just like Function s and rust functions, and you can even evaluate them on Vector s.
You can take its partial derivatives with the [claire_dxv!], [claire_dyv!] and [claire_dzv!] macros, adding the ‘v’ at the end
to signal that it is the partial of a vector function, and that it returns a Vector as such.
Furthermore, you can use the [curl!] and [div!] macro to evaluate its rotational and divergence at a point. \
 Examples
use claire_vector::*;
let v:VectorFunction = vector_function!(x, y, -y, x);
assert_eq!(v(0., 1.), vector!(-1, 0)); // v(0, 1) = (-1, 0)
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more 🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
The returned type after the call operator is used.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
The returned type after the call operator is used.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
The returned type after the call operator is used.
🔬 This is a nightly-only experimental API. (fn_traits)
Performs the call operation.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.